
0.4.11 (2016-09-15)
###################

Changes since 0.4.10 (2016-09-13).

Other Changes
$$$$$$$$$$$$$

* fixed `#357 <https://github.com/biocommons/hgvs/issues/357/>`_: reenable parsing of sequence with inversion (backed out `#340 <https://github.com/biocommons/hgvs/issues/340/>`_) [`BROKEN: 881c58dda474 <https://github.com/biocommons/hgvs/commit/881c58dda474>`_]

